@@ -1,13 +1,13 @@
-use crate::{color::Color, config::Config, position::Position};
-
 use clap::{
     builder::styling::{AnsiColor, Styles},
     Parser, Subcommand,
 };
 use serde::Deserialize;
 
+use crate::{color::Color, config::Config, position::Position};
+
 #[derive(Parser)]
-#[clap(version = "v0.1.215, (C) 2024 Oughie", hide_possible_values = true, styles = Self::STYLES)]
+#[clap(version = "v0.1.216, (C) 2024 Oughie", hide_possible_values = true, styles = Self::STYLES)]
 pub struct Args {
     #[clap(subcommand)]
     pub mode: Option<Mode>,
@@ -55,7 +55,7 @@ impl Args {
 pub enum Mode {
     #[doc = "Display the current time (default)"]
     Clock,
-    #[doc = "Create a timer"]
+    #[doc = "Create a timer (5 minutes if no time is specified)"]
     Timer(TimerArgs),
     #[doc = "Start a stopwatch"]
     Stopwatch,
@@ -63,8 +63,15 @@ pub enum Mode {
 
 #[derive(clap::Args, Clone, Deserialize)]
 pub struct TimerArgs {
-    #[doc = "Specify the timer duration in seconds"]
-    pub secs: u64,
+    #[doc = "Add seconds to the timer"]
+    #[clap(long, short = 'S')]
+    pub seconds: Option<u64>,
+    #[doc = "Add minutes to the timer"]
+    #[clap(long, short = 'M')]
+    pub minutes: Option<u64>,
+    #[doc = "Add hours to the timer"]
+    #[clap(long, short = 'H')]
+    pub hours: Option<u64>,
     #[doc = "Terminate the application when the timer finishes"]
     #[clap(long, short)]
     pub kill: bool,
